package com.aliyun.lindorm.sql.demo;

import com.alibaba.druid.pool.DruidDataSourceFactory;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.sql.DataSource;
import java.io.InputStream;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.Statement;
import java.util.Arrays;
import java.util.Properties;
import java.util.Random;

/**
 * @author jianhong.hjh
 * @date 2022/7/27 2:48 PM
 */
public class DruidPoolDemo {
  private static final Logger LOG = LoggerFactory.getLogger(DruidPoolDemo.class);

  public static void main(String[] args) throws Exception {
    // 加载参数
    Properties properties = new Properties();
    InputStream inputStream = DruidPoolDemo.class.getClassLoader().getResourceAsStream("druid.properties");
    properties.load(inputStream);
    // 初始化连接池
    DataSource dataSource = DruidDataSourceFactory.createDataSource(properties);

    /* -------------- 基于JDBC的CRUD示例 ----------------- */

    String tableName = "sql_table_" + new Random().nextInt(1000);
    // 创建表
    try (Connection connection = dataSource.getConnection()) {
      try (Statement statement = connection.createStatement()) {
        String sql = "create table if not exists " + tableName + "(id VARCHAR, name VARCHAR, primary key(id))";
        int ret = statement.executeUpdate(sql);
        System.out.println(ret);
      }
    }

    // 插入数据
    try (Connection connection = dataSource.getConnection()) {
      String sql = "upsert into " + tableName + "(id,name) values(?,?)";
      try (PreparedStatement ps = connection.prepareStatement(sql)) {
        int batchSize = 100;
        for (int i = 0; i < batchSize; i++) {
          ps.setString(1, "aa" + i);
          ps.setString(2, "bb" + i);
          // 加入批次
          ps.addBatch();
        }
        // 执行全部批次的写入。
        // 出于性能和稳定性考量，添加的批次数量不宜过大。
        // 建议一次executeBatch()写入的批次数最多在百级别。
        int[] ret = ps.executeBatch();
        System.out.println(Arrays.toString(ret));
      }
    }

    // 查询数据
    try (Connection connection = dataSource.getConnection()) {
      String sql = "select * from " + tableName + " where id=?";
      try (PreparedStatement ps = connection.prepareStatement(sql)) {
        ps.setString(1, "aa");
        ResultSet rs = ps.executeQuery();
        while (rs.next()) {
          String id = rs.getString(1);
          String name = rs.getString(2);
          System.out.println("id=" + id);
          System.out.println("name=" + name);
        }
      }
    }

    // 删除数据
    try (Connection connection = dataSource.getConnection()) {
      String sql = "delete from " + tableName + " where id=?";
      try (PreparedStatement ps = connection.prepareStatement(sql)) {
        ps.setString(1, "aa");
        ps.executeUpdate();
      }
    }
  }
}
